"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const anser_1 = __importDefault(require("anser"));
const highlightjs_1 = __importDefault(require("highlightjs"));
const katex_1 = __importDefault(require("katex"));
const nodom_1 = require("nodom");
const elementCreator_1 = __importDefault(require("./elementCreator"));
const htmlRenderer_1 = __importDefault(require("./htmlRenderer"));
const markdownRenderer_1 = __importDefault(require("./markdownRenderer"));
const renderer_1 = __importDefault(require("./renderer"));
function ansiCodesRenderer(input) {
    return anser_1.default.ansiToHtml(anser_1.default.escapeForHtml(input));
}
function codeHighlighter(code, lang) {
    return highlightjs_1.default.getLanguage(lang)
        ? highlightjs_1.default.highlight(lang, code).value
        : code;
}
function mathRenderer(tex) {
    return katex_1.default.renderToString(tex, { displayMode: true, throwOnError: false });
}
exports.default = (opts = {}) => {
    const doc = new nodom_1.Document();
    const elementCreator = elementCreator_1.default(doc.createElement.bind(doc), opts.classPrefix);
    const markdownRenderer = markdownRenderer_1.default(opts.markedOpts, opts.katexOpts);
    const dataRenderers = {
        'text/html': htmlRenderer_1.default({ elementCreator, mathRenderer }),
        ...opts.dataRenderers,
    };
    return renderer_1.default(elementCreator, {
        ansiCodesRenderer,
        codeHighlighter,
        dataRenderers,
        markdownRenderer,
        ...opts,
    });
};
//# sourceMappingURL=index.js.map